/**
 * Introduction
 *
 * @title ROV - Easy applications from C
 *
 * @copyright Jason Tribbeck / 7th ARM 1994-2001
 *
 * @authors Jason Tribbeck
 *
 * @file dir.h
 *
 * @type helper
 *
 * @description
 *
 * The dir functions are designed to scan directories, either recursively, or individually
 * reporting files, directories and/or image directories.
 */

#ifndef __rov_dir
#define __rov_dir


#ifdef __cplusplus
extern "C"
{
#endif

/**
 * Called by dirscan to indicate that an object meeting the criteria
 * has been found.
 * @param name the name of the object.
 * @param type the type of the object.
 * @param size the size of the object.
 * @see dir_scan
 * @see dir_scan2
 * @see dirscan2_proc
 */
typedef void (* dirscan_proc)(char *name,
			      int type, 
			      int size);

/**
 * Called by dirscan2 to indiacte that an object meeting the criteria
 * has been found.
 * @param name the name of the object.
 * @param type the type of the object.
 * @param size the size of the object.
 * @return a flag indicating what should happen. DIRSCAN_CONTINUE indicates that searching
 * should continue, DIRSCAN_BACKBYONE indicates that searching should continue from the object
 * before, DIRSCAN_RESTARTDIR indicates that the directory should be restart at the beginning.
 * The different return types can be used if a recursive deletion is taking place, for example.
 * @see dir_scan
 * @see dir_scan2
 * @see dirscan_proc
 * @see Scanning response codes
 */
typedef int (* dirscan2_proc)(char *name, 
			      int type, 
			      int size);

/**
 * Used to scan directories to look for objects that match certain criteria
 * @param dir_name the name of the directory to search in.
 * @param flags the find and search criteria.
 * @param wildcard the wildcard to use.
 * @param proc the function to call when a match is found.
 * @return success flag. Non-zero means success.
 * @see dirscan2_proc
 * @see Find and search flags
 */
int dir_scan(char *dir_name,
	     int flags,
	     char *wildcard,
	     dirscan_proc proc);

/**
 * Used to scan directories to look for objects that match certain criteria
 * @param dir_name the name of the directory to search in.
 * @param flags the find and search criteria.
 * @param wildcard the wildcard to use.
 * @param proc the function to call when a match is found.
 * @return success flag. Non-zero means success.
 * @see dirscan2_proc
 * @see Scanning response codes
 * @see Find and search flags
 */
int dir_scan2(char *dir_name,
	      int flags,
	      char *wildcard,
	      dirscan2_proc proc);

/**
 * @section Find and search flags
 */
#define DIRSCAN_RECURSE		(1<<0)
#define DIRSCAN_FILES		(1<<1)
#define DIRSCAN_DIRS		(1<<2)
#define DIRSCAN_IMAGEDIRS	(1<<3)
#define DIRSCAN_RECURSEIMAGEDIRS (1<<4)

/**
 * @section Scanning response codes
 * These are returned by the dirscan2_proc handler.
 * @see dirscan2_proc
 */
#define DIRSCAN_CONTINUE	(0)
#define DIRSCAN_BACKBYONE	(1)
#define DIRSCAN_RESTARTDIR	(2)


#ifdef __cplusplus
}
#endif

#endif
