/**
 * Introduction
 *
 * @title ROV - Easy applications from C
 *
 * @copyright Jason Tribbeck / 7th ARM 1994-2001
 *
 * @authors Jason Tribbeck
 *
 * @file template.h
 *
 * @type helper
 *
 * @description
 *
 * This is an experimental interface to the WIMP's template
 * calls.
 */

#ifndef __rov_template
#define __rov_template


#ifdef __cplusplus
extern "C"
{
#endif

/**
 * Open a template file.
 * @param file_name the name of the file.
 * @return non-zero for success, zero for failure.
 */
int template_open(char *file_name);

/**
 * Close a template file.
 * @return non-zero for success, zero for failure.
 */
int template_close(void);

/**
 * Create a canvas from a template.
 * @param name the template name.
 * @param ind_buffer the pointer to the start of the indirected data buffer.
 * @param ind_end the pointer to the end of the indirected data buffer.
 * @return the created canvas, or NULL if unable to create.
 * @note template_data is updated to point to the end of indirected
 * data after creating a canvas. This allows subsequent calls to fill up a
 * global buffer.
 * @see template_data
 */
canvas template_canvas(char *name,
		       char *ind_buffer,
		       char *ind_end);

/**
 * Sets the address of temporary workspace.
 * @param addr the address.
 */
void template_setworkspace(char *addr);

/**
 * Sets the sprite area pointer for subsequent template
 * canvas creation.
 * @param area the pointer to the sprite area.
 * @return the old pointer.
 */
void *template_setspritearea(void *area);

/**
 * Points to the end of the indirected data after creating a canvas.
 * @see template_canvas()
 */
extern char *template_data;


#ifdef __cplusplus
}
#endif

#endif
